python-route53
==============

:Info: A Python 2.7/3.x compatible Route53 module.
:Author: Greg Taylor

The ``python-route53`` Python package is a simple Python 3 compatible API for
Amazon's `Route 53`_.

Why not boto?
-------------

boto_ is a wonderful piece of software, one that I continue to contribute to.
However, we needed a Python 3 compatible route53 module, and boto has a long
way to go on this front.

I've also taken what I feel is a more simple, minimalistic API design. That
is entirely subjective, though, and boto is perfectly viable.

Getting started
---------------

Head on over and read the documentation_.

Current status
--------------

Beta, but generally useful to anyone. Great unit test coverage, good
documentation_.

License
-------

python-route53 is licensed under the BSD License.


.. _Route 53: http://aws.amazon.com/route53/
.. _boto: http://docs.pythonboto.org/
.. _issue tracker: https://github.com/gtaylor/python-route53/issues
.. _documentation: https://python-route53.readthedocs.org